package org.jeecg.modules.okki.wechatinnergroup.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.collection.ListUtil;
import cn.hutool.core.date.DatePattern;
import cn.hutool.core.lang.Console;
import cn.hutool.http.Header;
import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.lark.oapi.Client;
import com.lark.oapi.core.utils.Jsons;
import com.lark.oapi.service.bitable.v1.model.AppTableRecord;
import com.lark.oapi.service.bitable.v1.model.CreateAppTableRecordReq;
import com.lark.oapi.service.bitable.v1.model.CreateAppTableRecordResp;
import com.volcengine.ark.runtime.model.completion.chat.ChatCompletionChoice;
import com.volcengine.ark.runtime.model.completion.chat.ChatCompletionRequest;
import com.volcengine.ark.runtime.model.completion.chat.ChatMessage;
import com.volcengine.ark.runtime.model.completion.chat.ChatMessageRole;
import com.volcengine.ark.runtime.service.ArkService;
import lombok.extern.slf4j.Slf4j;
import okhttp3.ConnectionPool;
import okhttp3.Dispatcher;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.jeecg.common.util.DateUtil;
import org.jeecg.common.util.FastJsonUtil;
import org.jeecg.common.util.ThreadPoolUtil;
import org.jeecg.modules.okki.site.entity.FeiShuConfigEnum;
import org.jeecg.modules.okki.site.entity.FeiShuConfigManager;
import org.jeecg.modules.okki.site.entity.OkkiSite;
import org.jeecg.modules.okki.site.service.IOkkiSiteService;
import org.jeecg.modules.okki.utils.HttpClientUtils;
import org.jeecg.modules.okki.wechatgroup.dto.WechatInnerGroupMsgRespDto;
import org.jeecg.modules.okki.wechatinnergroup.dto.GroupMsgResult;
import org.jeecg.modules.okki.wechatinnergroup.entity.OkkiShopWechatInnerGroupMsg;
import org.jeecg.modules.okki.wechatinnergroup.mapper.OkkiShopWechatInnerGroupMsgMapper;
import org.jeecg.modules.okki.wechatinnergroup.service.IOkkiShopWechatInnerGroupMsgService;
import org.jeecg.modules.okki.wechatinnergroup.service.WechatInnerGroupMongodbRepository;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.mongodb.core.aggregation.AggregationResults;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.ParseException;
import java.time.Duration;
import java.util.*;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicReference;
import java.util.stream.Collectors;

/**
 * @Description: okki_shop_wechat_inner_group_msg
 * @Author: jeecg-boot
 * @Date: 2025-02-17
 * @Version: V1.0
 */
@Slf4j
@Service
public class OkkiShopWechatInnerGroupMsgServiceImpl extends ServiceImpl<OkkiShopWechatInnerGroupMsgMapper, OkkiShopWechatInnerGroupMsg> implements IOkkiShopWechatInnerGroupMsgService {

    @Value("${OKKI.BASE_URL}")
    private String URL;

    @Value("${OKKI.CLIENT_SECRET}")
    private String CLIENT_SECRET;

    @Resource
    private OkkiShopWechatInnerGroupMsgMapper okkiShopWechatInnerGroupMsgMapper;

    @Resource
    private WechatInnerGroupMongodbRepository wechatInnerGroupMongodbRepository;

    @Resource
    private IOkkiSiteService okkiSiteService;

    /**
     * 获取站点信息
     *
     * @param siteId
     * @return
     */
    @Override
    public void getSiteWechatInnerMsgMaxSeqByMysql(String siteId) {
        List<OkkiShopWechatInnerGroupMsg> shopWechatInnerGroupMsgs = okkiShopWechatInnerGroupMsgMapper.getSiteWechatInnerMsgList(siteId);
        log.info("一共有：{}个站点,需要【企业微信-内部群】消息", shopWechatInnerGroupMsgs.size());
        for (int i = 0; i < shopWechatInnerGroupMsgs.size(); i++) {
            int finalI = i;
            ThreadPoolUtil.execute(() -> {
                OkkiShopWechatInnerGroupMsg okkiShopWechatInnerGroupMsg = shopWechatInnerGroupMsgs.get(finalI);
                int maxSeq = okkiShopWechatInnerGroupMsg.getSeq() == 0 ? 1 : okkiShopWechatInnerGroupMsg.getSeq();
                log.info("开始处理第{}个，站点ID为：{},seq为：{},【企业微信-内部群】消息", finalI + 1, okkiShopWechatInnerGroupMsg.getSiteId(), maxSeq);
                saveWechatInnerGroupMsg(String.valueOf(okkiShopWechatInnerGroupMsg.getSiteId()), maxSeq, "mysql");
            });
        }
    }

    @Override
    public void getSiteWechatInnerMsgMaxSeqByMongodb(String siteId) {
        QueryWrapper<OkkiSite> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotBlank(siteId)) {
            queryWrapper.eq("site_id", siteId);
        }
        queryWrapper.eq("del_flag", 0);
        List<OkkiSite> okkiSites = okkiSiteService.list(queryWrapper);

        log.info("一共有：{}个站点,需要【企业微信-内部群】消息", okkiSites.size());
        for (int i = 0; i < okkiSites.size(); i++) {
            int finalI = i;
            ThreadPoolUtil.execute(() -> {
                AggregationResults<GroupMsgResult> aggregationResults = wechatInnerGroupMongodbRepository.findMaxSeqBySiteId(Integer.valueOf(okkiSites.get(finalI).getSiteId()));
                log.info("aggregationResults:{}", FastJsonUtil.toJSONString(aggregationResults));

                long maxSeq = 1;
                if (!CollectionUtil.isEmpty(aggregationResults)) {
                    GroupMsgResult groupMsgResult = aggregationResults.getMappedResults().get(0);
                    maxSeq = groupMsgResult.getMaxSeq();
                }

                log.info("开始处理第{}个，站点ID为：{},seq为：{},【企业微信-内部群】消息", finalI + 1, okkiSites.get(finalI).getSiteId(), maxSeq);
                saveWechatInnerGroupMsg(okkiSites.get(finalI).getSiteId(), Math.toIntExact(maxSeq), "mongodb");
            });
        }
    }

    /**
     * 保存【企业微信-内部群】消息
     *
     * @param siteId
     * @param minSeq
     */
    public void saveWechatInnerGroupMsg(String siteId, Integer minSeq, String type) {
        List<OkkiShopWechatInnerGroupMsg> wechatInnerGroupMsgList = sendWechatInnerGroupMsgRequest(siteId, minSeq);
        log.info("获取站点ID为：{},seq为：{},【企业微信-内部群】消息 条数一共有：{}", siteId, minSeq, wechatInnerGroupMsgList.size());
        List<OkkiShopWechatInnerGroupMsg> shopWechatInnerGroupMsgs = new ArrayList<>();
        if (!CollectionUtils.isEmpty(wechatInnerGroupMsgList)) {
            // 循环处理数据，请求下一页
            wechatInnerGroupMsgList.forEach(c -> {
                OkkiShopWechatInnerGroupMsg shopWechatInnerGroupMsg = new OkkiShopWechatInnerGroupMsg();
                shopWechatInnerGroupMsg.setMsgId(c.getMsgId());
                shopWechatInnerGroupMsg.setRoomId(c.getRoomId());
                shopWechatInnerGroupMsg.setSeq(c.getSeq());
                shopWechatInnerGroupMsg.setAction(c.getAction());
                shopWechatInnerGroupMsg.setFromId(StringUtils.isNotBlank(c.getFrom()) ? c.getFrom() : "");
                shopWechatInnerGroupMsg.setTolist(c.getTolist());
                shopWechatInnerGroupMsg.setMsgType(c.getMsgType());
                shopWechatInnerGroupMsg.setMsgTime(c.getMsgTime());
                shopWechatInnerGroupMsg.setContent(c.getContent());
                shopWechatInnerGroupMsg.setClientId(c.getClientId());
                shopWechatInnerGroupMsg.setSiteId(c.getSiteId());
                shopWechatInnerGroupMsg.setCreateTime(c.getCreateTime());
                shopWechatInnerGroupMsg.setUpdateTime(c.getUpdateTime());
                if ("text".equals(c.getMsgType())) {
                    shopWechatInnerGroupMsg.setDealStatus(0);
                } else {
                    shopWechatInnerGroupMsg.setDealStatus(1);
                }
                shopWechatInnerGroupMsgs.add(shopWechatInnerGroupMsg);
            });

            if ("mongodb".equals(type)) {
                wechatInnerGroupMongodbRepository.saveAll(shopWechatInnerGroupMsgs);
            } else {
                this.saveBatch(shopWechatInnerGroupMsgs);
            }

            //获取下一页数据
            OkkiShopWechatInnerGroupMsg lastWechatInnerGroupMsg = shopWechatInnerGroupMsgs.get(shopWechatInnerGroupMsgs.size() - 1);
            saveWechatInnerGroupMsg(siteId, lastWechatInnerGroupMsg.getSeq(), type);
        }
    }

    /**
     * 发送获取企业微信群消息请求
     *
     * @param siteId
     */
    public List<OkkiShopWechatInnerGroupMsg> sendWechatInnerGroupMsgRequest(String siteId, Integer minSeq) {
        List<OkkiShopWechatInnerGroupMsg> okkiShopWechatInnerGroupMsgs = new ArrayList<>();
        // 请求okki平台接口
        Map<String, String> query = new TreeMap<>();
        query.put("sign_method", "hmac-md5");
        query.put("timestamp", String.valueOf(System.currentTimeMillis()));
        query.put("site_id", String.valueOf(siteId));
        query.put("method", "query_wechat_group_msg");

        Map<String, Object> postData = new HashMap<>();
        postData.put("page", 1);
        postData.put("page_size", 100);
        postData.put("min_seq", minSeq);
        postData.put("group_type", 1);

        try {
            String queryStr = HttpClientUtils.buildQueryString(query);
            String body = HttpClientUtils.toJsonString(postData);
            String signStr = queryStr + body;
            query.put("signature", HttpClientUtils.generateHmacMD5(signStr, CLIENT_SECRET));
            String okkiUrl = URL + "?" + HttpClientUtils.buildQueryString(query);
            log.info("url:" + okkiUrl + ",body:" + body);
            String msgResult = HttpClientUtils.doPost(okkiUrl, body);
            // {"code":0,"msg":"success","now":"2024-09-09 09:42:28","data":[]}
            WechatInnerGroupMsgRespDto wechatInnerGroupMsgRespDto = JSONObject.parseObject(msgResult, WechatInnerGroupMsgRespDto.class);
//            log.info("wechatGroupMsgRespDto:{}",FastJsonUtil.toJSONString(wechatGroupMsgRespDto));
            if (wechatInnerGroupMsgRespDto.getCode() != 0) {
                throw new RuntimeException(wechatInnerGroupMsgRespDto.getMsg());
            }
            okkiShopWechatInnerGroupMsgs = wechatInnerGroupMsgRespDto.getData();
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
        return okkiShopWechatInnerGroupMsgs;
    }

    /**
     * 获取企业微信内部群消息任务
     */
    @Override
    public void getInnerGroupTaskMsg(String siteId) {
        log.info("-------- 开始获取【企业微信内部群】任务消息 siteId：{} -------", siteId);
//        String endDay = "2025-02-01";
//        String endDay = DateUtil.dateToString(DateUtil.addDate(new Date(),-1,3),DateUtil.DATE_FORMAT_ONE);
//        log.info("查询截止时间: {}", endDay);

        String modelType = "normal";
        QueryWrapper<OkkiShopWechatInnerGroupMsg> queryWrapper = new QueryWrapper<>();

        if ("normal".equals(modelType)) {
            queryWrapper.like("content", "收到「");
        }

        if (StringUtils.isNotBlank(siteId)) {
            queryWrapper.eq("site_id", siteId);
        }

        queryWrapper.notLike("from_id","@xiaoman.cn");
        queryWrapper.eq("msg_type", "text");
        queryWrapper.eq("deal_status", 0);
//        queryWrapper.gt("msg_time", endDay);
        queryWrapper.orderByAsc("msg_time");

        List<OkkiShopWechatInnerGroupMsg> taskMsgs = this.list(queryWrapper);
        log.info("taskMsgs:{}", FastJsonUtil.toJSONString(taskMsgs));

        if (CollectionUtil.isEmpty(taskMsgs)) {
            // 将处理过的消息 设为已处理
            taskMsgs.forEach(c -> {
                UpdateWrapper<OkkiShopWechatInnerGroupMsg> updateWrapper = new UpdateWrapper<>();
                updateWrapper.eq("msg_id", c.getMsgId());
                updateWrapper.set("deal_status", 1);
                this.update(updateWrapper);
            });
            return;
        }

        Map<Integer, List<OkkiShopWechatInnerGroupMsg>> groupedBySiteId =
                taskMsgs.stream().collect(Collectors.groupingBy(OkkiShopWechatInnerGroupMsg::getSiteId));

        for (Map.Entry<Integer, List<OkkiShopWechatInnerGroupMsg>> entry : groupedBySiteId.entrySet()) {
            Integer entryKey = entry.getKey();
            List<OkkiShopWechatInnerGroupMsg> messages = entry.getValue();
            log.info("Site ID: {}, Message Count: {}", entryKey, messages.size());

            if ("normal".equals(modelType)) {
                // 普通模式，直接同步任务到飞书
                log.info("一共有：{}个任务 需要同步至飞书多维表格", messages.size());
                log.info("messages:{}", FastJsonUtil.toJSONString(messages));
                messages.forEach(c -> {
                    // 同步任务至飞书
                    syncInnerGroupTaskToFeiShuSheet(c);
                });

            } else {
                // AI 处理模式
                String aiResp = getTaskByAIContent(messages);
                log.info("aiResp:{}", aiResp);
                if (StringUtils.isNotBlank(aiResp) &&
                        !"请求失败，请重试！".equals(aiResp) &&
                        !"[]".equals(aiResp)) {
                    JSONArray jsonArray = new JSONArray(JSON.parseArray(aiResp));
                    for (int i = 0; i < jsonArray.size(); i++) {
                        JSONObject jsonObject = jsonArray.getJSONObject(i);
                        log.info("解析出的任务: {}", jsonObject.toJSONString());

                        OkkiShopWechatInnerGroupMsg innerGroupMsg = new OkkiShopWechatInnerGroupMsg();
                        innerGroupMsg.setSiteId(Integer.valueOf(jsonObject.getString("siteId")));
                        innerGroupMsg.setFromId(jsonObject.getString("sender"));
                        innerGroupMsg.setContent(jsonObject.getString("content"));
                        innerGroupMsg.setMsgTime(jsonObject.getDate("msgTime"));
                        innerGroupMsg.setTaskType(jsonObject.getString("taskType"));
                        innerGroupMsg.setTaskDay(jsonObject.getString("taskDay"));
                        innerGroupMsg.setTaskUser(jsonObject.getString("taskUser"));

                        syncInnerGroupTaskToFeiShuSheet(innerGroupMsg);
                    }
                }
            }

            // 将处理过的消息 设为已处理
            messages.forEach(c -> {
                UpdateWrapper<OkkiShopWechatInnerGroupMsg> updateWrapper = new UpdateWrapper<>();
                updateWrapper.eq("msg_id", c.getMsgId());
                updateWrapper.set("deal_status", 1);
                this.update(updateWrapper);
            });

            log.info("-------- 站点ID:{}，获取【企业微信内部群】任务消息结束 -------", entryKey);
        }

    }

    /**
     * 根据AI内容获取任务
     * @param taskMsgs
     * @return
     */
    public String getTaskByAIContent(List<OkkiShopWechatInnerGroupMsg> taskMsgs) {
        // ok user
        Set<String> okUsers = new HashSet<>(Arrays.asList(
                "roc", "tina", "lvy", "miya", "ash", "hardy", "emma", "bella", "kevin", "cora",
                "jane", "chloe", "lucy", "oliver", "bailey", "lyn", "giselle", "polly", "lily",
                "janne", "neo", "viani", "eva", "mick"
        ));

        JSONArray recordArray = new JSONArray();
        taskMsgs.forEach(c -> {
            JSONObject jsonRecord = new JSONObject();
            String sender = okUsers.contains(c.getFromId()) ? c.getFromId() : "小满";

            jsonRecord.put("sender", sender);
            jsonRecord.put("siteId", c.getSiteId());
            jsonRecord.put("msgId", c.getMsgId());
            jsonRecord.put("content", c.getContent());
            jsonRecord.put("msgTime", DateUtil.dateToString(DateUtil.formatDate(c.getMsgTime(), DateUtil.DATE_FORMAT_FIVE), DateUtil.DATE_FORMAT_FIVE));
            recordArray.add(jsonRecord);
        });

        String jsonData = FastJsonUtil.toJSONString(recordArray);
        log.info("jsonData：{}", jsonData);

        String pormpt = "你需要根据接收到的消息内容识别工作任务，并生成标准化响应。请严格遵循以下处理流程：\n" +
                "\n" +
                "首先，检查消息内容是否包含以下7个核心关键词：\n" +
                "<任务映射表>\n" +
                "1. 预版式设计 → 预版式设计-建站专员 (2工作日)\n" +
                "2. 版式设计 → 版式设计-建站专员 (2工作日)\n" +
                "3. 资料回收 → 资料回收-资料专员 (2工作日)\n" +
                "4. 拓词 → 关键词拓词-SEO专员 (3工作日)\n" +
                "5. 网站内容填充 → 网站内容填充-资料专员 (5工作日)\n" +
                "6. banner设计 → banner设计-UI设计 (3工作日)\n" +
                "7. 网站细节修改 → 网站细节修改-建站专员 (2工作日)\n" +
                "</任务映射表>\n" +
                "\n" +
                "处理步骤：\n" +
                "1. 逐句扫描" + jsonData + "中的文本\n" +
                "2. 按顺序检测content字段是否包含映射表中的精确关键词（中文字符需完全匹配）\n" +
//                "3. 发现首个匹配的关键词后立即停止扫描\n" +
                "3. 根据映射表生成对应的：\n" +
                "   - taskType：任务类型全称\n" +
                "   - taskDay：\"预计在X个工作日内完成\"中的X\n" +
//                "   - content：标准响应模板\n" +
                "   - taskUser：获取检查content字段@的谁\n" +
                "4. 按顺序提取以下数据元素：\n" +
                "   a. siteId（从原始数据获取）\n" +
                "   b. sender（从原始数据获取）\n" +
                "   c. content（从原始数据获取）\n" +
                "   d. msgId（从原始数据获取）\n" +
                "   e. msgTime（从原始数据获取，格式化为yyyy-MM-dd HH:mm:ss）\n" +
                "5. 若未检测到任何关键词，返回\"[]\"\n" +
                "\n" +
                "输出要求：\n" +
                "- 生成紧凑的JSON数组（无换行符）\n" +
                "- 字段顺序必须为：siteId,sender, content, msgId, msgTime, taskType, taskDay\n" +
                "- 所有字符串值使用双引号包裹\n" +
                "- 严格使用英文标点符号\n" +
                "- 禁止添加任何解释性文字\n" +
                "\n" +
                "示例输出：\n" +
                "[{\"siteId\":\"123\",\"sender\":\"客户A\",\"content\":\"好的，已收到「版式设计」任务，预计2个工作日内完成。\",\"msgId\":\"MSG002\",\"msgTime\":\"2023-08-15 14:30:00\",\"taskType\":\"版式设计-建站专员\",\"taskDay\":\"2\",\"taskUser\":\"小明\"}]\n";

        log.info("pormpt：{}", pormpt);

        ConnectionPool connectionPool = new ConnectionPool(5, 1, TimeUnit.SECONDS);
        Dispatcher dispatcher = new Dispatcher();
        ArkService service = ArkService.builder()
                .timeout(Duration.ofSeconds(1800))
                .connectTimeout(Duration.ofSeconds(20))
                .dispatcher(dispatcher)
                .connectionPool(connectionPool).baseUrl("https://ark.cn-beijing.volces.com/api/v3")
                .apiKey("d3371a7b-9ebd-4a23-a73c-8f2f4b7da98d").build();

        List<ChatMessage> messages = new ArrayList<>();
        ChatMessage userMessage = ChatMessage.builder().role(ChatMessageRole.USER).content(pormpt).build();
        messages.add(userMessage);
        ChatCompletionRequest chatCompletionRequest = ChatCompletionRequest.builder()
                .model("deepseek-r1-250120")
                .messages(messages)
                .build();

//        String result = "";
//        for (ChatCompletionChoice choice : service.createChatCompletion(chatCompletionRequest).getChoices()) {
//            System.out.println(choice.getMessage().getReasoningContent());
//            result = choice.getMessage().getContent().toString();
//        }
//        return result;

        AtomicReference<String> result = new AtomicReference<>("");

        List<ChatCompletionChoice> choices = service.createChatCompletion(chatCompletionRequest).getChoices();
        if (choices.isEmpty()) {
            log.warn("没有返回结果");
            return "[]";
        }

        choices.forEach(choice -> {
            log.info("getReasoningContent():{}", choice.getMessage().getReasoningContent());
            String content = choice.getMessage().getContent().toString();
            result.set(content != null ? content : "[]");
        });

        return result.get();
    }

    /**
     * 获取AI回复
     *
     * @param taskMsgs
     * @return
     */
    public String getTaskByAIContent2(List<OkkiShopWechatInnerGroupMsg> taskMsgs) {
        // ok user
        Set<String> okUsers = new HashSet<>(Arrays.asList(
                "roc", "tina", "lvy", "miya", "ash", "hardy", "emma", "bella", "kevin", "cora",
                "jane", "chloe", "lucy", "oliver", "bailey", "lyn", "giselle", "polly", "lily",
                "janne", "neo", "viani", "eva", "mick"
        ));

        JSONArray recordArray = new JSONArray();
        taskMsgs.forEach(c -> {
            JSONObject jsonRecord = new JSONObject();
            String sender = okUsers.contains(c.getFromId()) ? c.getFromId() : "小满";

            jsonRecord.put("sender", sender);
            jsonRecord.put("siteId", c.getSiteId());
            jsonRecord.put("msgId", c.getMsgId());
            jsonRecord.put("content", c.getContent());
            jsonRecord.put("msgTime", DateUtil.dateToString(DateUtil.formatDate(c.getMsgTime(), DateUtil.DATE_FORMAT_FIVE), DateUtil.DATE_FORMAT_FIVE));
            recordArray.add(jsonRecord);
        });
        log.info("recordArray：{}", FastJsonUtil.toJSONString(recordArray));
        String jsonData = FastJsonUtil.toJSONString(recordArray);

        JSONObject json = new JSONObject();
        JSONArray messageArr = new JSONArray();

        JSONObject sysMsgJson = new JSONObject();
        sysMsgJson.put("role", "system");
        sysMsgJson.put("content", "#角色 任务分配协调员：根据任务类型，将任务分配给合适的角色（如建站专员、SEO 专员、资料专员等）。");
        messageArr.add(sysMsgJson);

        String pormpt = "你需要根据接收到的消息内容识别工作任务，并生成标准化响应。请严格遵循以下处理流程：\n" +
                "\n" +
                "首先，检查消息内容是否包含以下7个核心关键词：\n" +
                "<任务映射表>\n" +
                "1. 预版式设计 → 预版式设计-建站专员 (2工作日)\n" +
                "2. 版式设计 → 版式设计-建站专员 (2工作日)\n" +
                "3. 资料回收 → 资料回收-资料专员 (2工作日)\n" +
                "4. 拓词 → 关键词拓词-SEO专员 (3工作日)\n" +
                "5. 网站内容填充 → 网站内容填充-资料专员 (5工作日)\n" +
                "6. banner设计 → banner设计-UI设计 (3工作日)\n" +
                "7. 网站细节修改 → 网站细节修改-建站专员 (2工作日)\n" +
                "</任务映射表>\n" +
                "\n" +
                "处理步骤：\n" +
                "1. 逐句扫描" + jsonData + "中的文本\n" +
                "2. 按顺序检测content字段是否包含映射表中的精确关键词（中文字符需完全匹配）\n" +
//                "3. 发现首个匹配的关键词后立即停止扫描\n" +
                "3. 根据映射表生成对应的：\n" +
                "   - taskType：任务类型全称\n" +
                "   - taskDay：\"预计在X个工作日内完成\"中的X\n" +
//                "   - content：标准响应模板\n" +
                "   - taskUser：获取检查content字段@的谁\n" +
                "4. 按顺序提取以下数据元素：\n" +
                "   a. siteId（从原始数据获取）\n" +
                "   b. sender（从原始数据获取）\n" +
                "   c. content（从原始数据获取）\n" +
                "   d. msgId（从原始数据获取）\n" +
                "   e. msgTime（从原始数据获取，格式化为yyyy-MM-dd HH:mm:ss）\n" +
                "5. 若未检测到任何关键词，返回\"暂无任务\"\n" +
                "\n" +
                "输出要求：\n" +
                "- 生成紧凑的JSON数组（无换行符）\n" +
                "- 字段顺序必须为：siteId,sender, content, msgId, msgTime, taskType, taskDay\n" +
                "- 所有字符串值使用双引号包裹\n" +
                "- 严格使用英文标点符号\n" +
                "- 禁止添加任何解释性文字\n" +
                "\n" +
                "示例输出：\n" +
                "[{\"siteId\":\"123\",\"sender\":\"客户A\",\"content\":\"好的，已收到「版式设计」任务，预计2个工作日内完成。\",\"msgId\":\"MSG002\",\"msgTime\":\"2023-08-15 14:30:00\",\"taskType\":\"版式设计-建站专员\",\"taskDay\":\"2\",\"taskUser\":\"小明\"}]\n";

        log.info("pormpt：{}", pormpt);

        JSONObject userMsgJson = new JSONObject();
        userMsgJson.put("role", "user");
        userMsgJson.put("content", pormpt);
        messageArr.add(userMsgJson);

//        JSONObject assistantMsgJson = new JSONObject();
//        assistantMsgJson.put("role", "assistant");
//        assistantMsgJson.put("content", "```json\n");
//        assistantMsgJson.put("prefix", true);
//        messageArr.add(assistantMsgJson);

        json.put("messages", messageArr);
        json.put("stream", false);
//        json.put("model", "deepseek-ai/DeepSeek-R1");
//        json.put("model", "deepseek-ai/DeepSeek-V3");

//        json.put("model", "claude-3-5-sonnet-latest");

//        json.put("model", "deepseek-reasoner");
//        json.put("model", "deepseek-chat");

        json.put("model", "deepseek-r1-250120");
//        json.put("model", "doubao-pro-32k-241215");
//        json.put("model", "doubao-1-5-pro-256k-250115");

        log.info("json：{}", json.toJSONString());

//        String url = "http://100.21.172.224:3000";
//        String token = "sk-JZ53u4PJKTzdQVnF5c068f09DbCb451cAc7cDbF420FdD666";

//        String url = "https://api.siliconflow.cn";
//        String token = "sk-nnckizoasmqpvvtmiigmvntqdfxscsazxvsxxcqgzojnsmds";

//        String url = "https://api.deepseek.com";
//        String url = "https://api.deepseek.com/beta";
//        String token = "sk-1d5bf2fcb29d4299a23231163d81b91a";

        String url = "https://ark.cn-beijing.volces.com/api";
        String token = "d3371a7b-9ebd-4a23-a73c-8f2f4b7da98d";

        HttpResponse httpResponse = HttpRequest.post(url + "/v3/chat/completions")
                .header(Header.AUTHORIZATION, "Bearer " + token)
                .timeout(1000 * 60 * 5)
                .body(json.toJSONString())
                .execute();
        Console.log(httpResponse);

        String result = "";
        int status = httpResponse.getStatus();

        if (status == 200) {
            String getRespResult = httpResponse.body();
            log.info("getRespResult:{}", getRespResult);
            JSONObject respJson = JSONObject.parseObject(getRespResult);
            JSONObject jsonChocieObject = respJson.getJSONArray("choices").getJSONObject(0);
            JSONObject jsonMessage = jsonChocieObject.getJSONObject("message");
            result = jsonMessage.getString("content");
        } else {
            result = "请求失败，请重试！";
        }

        log.info("answerText:{}", result);
        return result;
    }

    /**
     * 保存内部群任务至飞书多维表格
     */
    public void syncInnerGroupTaskToFeiShuSheet(OkkiShopWechatInnerGroupMsg taskMsg) {
        FeiShuConfigEnum configEnum = FeiShuConfigManager.getInstance().getConfigEnum();
        Client client = Client.newBuilder(configEnum.getAppId(), configEnum.getAppSecret()).build();

        Map<String, Object> map = new HashMap<>();
        map.put("网站ID", taskMsg.getSiteId());
        map.put("任务状态", "未完成");
        map.put("企微任务领取人", taskMsg.getFromId().toLowerCase());
        map.put("任务内容", taskMsg.getContent());
        map.put("任务领取时间", taskMsg.getMsgTime().getTime());
        map.put("任务时长 / 工作日", taskMsg.getTaskDay());
        map.put("企微任务执行人", taskMsg.getTaskUser());
        map.put("任务类型", taskMsg.getTaskType());
        CreateAppTableRecordReq req = CreateAppTableRecordReq.newBuilder().appToken(configEnum.getAppToken()).tableId(configEnum.getTaskTableId())
                .appTableRecord(AppTableRecord.newBuilder()
                        .fields(map)
                        .build())
                .build();

        // 发起请求
        CreateAppTableRecordResp resp = null;
        try {
            resp = client.bitable().v1().appTableRecord().create(req);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            throw new RuntimeException(e);
        }

        String syncStatus = "成功";
        if (!resp.success()) {
            log.error("执行 **** syncInnerGroupTaskToFeiShuSheet **** 同步 【企业微信内容群任务】 到飞书表格 失败:{}", String.format("code:%s,msg:%s,reqId:%s", resp.getCode(), resp.getMsg(), resp.getRequestId()));
            syncStatus = "失败";
        }

//        log.info(Jsons.DEFAULT.toJson(resp.getData()));

//        feiShuMsgService.sendSyncFeiShuSheetMsg(okkiSite.getCompanyName(), okkiSite.getSiteId(), okkiSite.getTcName(), syncStatus);
//        return resp.getData().getRecord().getRecordId();
    }
}
